enum DecoderError {
NoEntries,
IcoEntryTooManyPlanesOrHotspot,
IcoEntryTooManyBitsPerPixelOrHotspot,
PngShorterThanHeader,
PngNotRgba,
InvalidDataSize,
ImageEntryDimensionMismatch {
format: IcoEntryImageFormat,
entry: (u16, u16),
image: (u32, u32),
},
}Expand description
Errors that can occur during decoding and parsing an ICO image or one of its enclosed images.
Variants
NoEntries
The ICO directory is empty
IcoEntryTooManyPlanesOrHotspot
The number of color planes (0 or 1), or the horizontal coordinate of the hotspot for CUR files too big.
IcoEntryTooManyBitsPerPixelOrHotspot
The bit depth (may be 0 meaning unspecified), or the vertical coordinate of the hotspot for CUR files too big.
PngShorterThanHeader
The entry is in PNG format and specified a length that is shorter than PNG header.
PngNotRgba
The enclosed PNG is not in RGBA, which is invalid: https://blogs.msdn.microsoft.com/oldnewthing/20101022-00/?p=12473/.
InvalidDataSize
The entry is in BMP format and specified a data size that is not correct for the image and optional mask data.
ImageEntryDimensionMismatch
The dimensions specified by the entry does not match the dimensions in the header of the enclosed image.